<?php
/**
*
* @author Daniel CHALSECHE (Dakin Quelia) dakinquelia@hotmail.com
* @package phpBB3
* @version $Id: attachview.php, v0.0.1 2010/01/15 14:25:22 Dakin Quelia Exp $
* @copyright (c) 2008 http://www.danielchalseche.be
* @license http://opensource.org/licenses/gpl-license.php GNU Public License
*
*/

/**
* @ignore
*/
define('IN_PHPBB', true);
$phpbb_root_path = (defined('PHPBB_ROOT_PATH')) ? PHPBB_ROOT_PATH : './../';
$phpEx = substr(strrchr(__FILE__, '.'), 1);
include($phpbb_root_path . 'common.' . $phpEx);

// Start session management
$user->session_begin();
$auth->acl($user->data);
$user->setup('mods/info_acp_attachview');

if (!$auth->acl_get('u_can_dl_wiew'))
{
	trigger_error('NOT_AUTHORISED');
}

page_header($user->lang['ATTACHVIEW'], false);

// Get some variables
$mode = request_var('mode', '');
$file = request_var('file', 0);
$user_id = $user->data['user_id'];
$whois_ip = request_var('ip', '');

// Check attachment is existing.
$sql = 'SELECT * FROM ' . ATTACHMENTS_TABLE . "
	WHERE attach_id = $file";
$result = $db->sql_query($sql);
$attach_id = (int) $db->sql_fetchfield('attach_id');
$db->sql_freeresult($result);

if (!$attach_id)
{
	trigger_error('NO_FILE');
}

// Whois requested
if ($mode == 'whois' && $auth->acl_get('a_') && $whois_ip)
{
	include($phpbb_root_path . 'includes/functions_user.' . $phpEx);

	$template->assign_var('WHOIS', user_ipwhois($whois_ip));

	// Output the page
	$template->set_filenames(array(
		'body' => 'viewonline_whois.html')
	);

	page_footer();
}

// Get userlist
$sql_all = 'SELECT COUNT(*) AS nb, a.user_id, a.user_ip, MAX(a.date) as max_date FROM ' . USERS_TABLE . ' u, ' . ATTACHVIEW_TABLE . ' a
		WHERE u.user_id = a.user_id
			AND a.attach_id = ' . $file . '
		GROUP BY IF(a.user_id != ' . ANONYMOUS . ', a.user_id, a.user_ip)';
$result_all = $db->sql_query($sql_all);

$total = 0;
$max_dates = $nb = array();

while ($row_all = $db->sql_fetchrow($result_all))
{
	$max_dates[] = $row_all['max_date'];

	$sort_field = ($row_all['user_id'] != ANONYMOUS) ? $row_all['user_id'] : $row_all['user_ip'];
	$nb[$sort_field] = $row_all['nb'];
}
$db->sql_freeresult($result);

$sql = 'SELECT u.user_id, u.username, u.username_clean, u.user_type, u.user_colour, a.user_ip, a.date, a.user_referer
	FROM ' . ATTACHVIEW_TABLE . ' a, ' . USERS_TABLE . ' u
		WHERE u.user_id = a.user_id AND a.attach_id = ' . $file . '
			' . ((sizeof($max_dates)) ? 'AND ' . $db->sql_in_set('a.date', $max_dates) : '') . '
	GROUP BY IF(a.user_id != ' . ANONYMOUS . ', a.user_id, a.user_ip)
	ORDER BY a.date DESC, u.username_clean';
$result = $db->sql_query($sql);

while ($row = $db->sql_fetchrow($result))
{
	$user_colour = ($row['user_colour']) ? ' style="color:#' . $row['user_colour'] . '" class="username-coloured"' : '';
	$username = ($row['user_id'] != ANONYMOUS) ? $row['username'] : $user->lang['GUEST'];
	$username_full = ($row['user_type'] != USER_IGNORE) ? get_username_string('full', $row['user_id'], $username, $row['user_colour']) : '<span' . $user_colour . '>' . $username . '</span>';

	$total++;

	$sort_field = ($row['user_id'] != ANONYMOUS) ? $row['user_id'] : $row['user_ip'];

	// Send vars to template
	$template->assign_block_vars('user_row', array(
		'USERNAME_FULL'		=> $username_full,
		'USER_IP'		=> $row['user_ip'],
		'USER_REF'		=> (strpos($row['user_referer'], $config['server_name']) === false) ? $row['user_referer'] : '',
		'DATES'			=> $user->format_date($row['date']),
		'NB'			=> $nb[$sort_field],
		'U_WHOIS'		=> append_sid("{$phpbb_root_path}download/attachview.$phpEx", 'file=' . $file . '&amp;mode=whois&amp;ip=' . $row['user_ip'])
	));
}
$db->sql_freeresult($result);

$template->assign_vars(array(
	'TOTAL_DOWNLOADERS'	=> ($total == 1) ? sprintf($user->lang['AV_TOTAL_DOWNLOADER'], $total) : sprintf($user->lang['AV_TOTAL_DOWNLOADERS'], $total),
));

// What time is it ?
$now = time();

// Get total views and start time for this topic
$sql_infos = 'SELECT COUNT(*) as total, MIN(date) as date FROM ' . ATTACHVIEW_TABLE . '
		WHERE attach_id = ' . $file;
$result_infos = $db->sql_query($sql_infos);
$row_infos = $db->sql_fetchrow($result_infos);
$db->sql_freeresult($result_infos);

// Lets go...
$current = $row_infos['date'];
$total_downloads = $row_infos['total'];

while ($current && $current < $now)
{
	$next = mktime(0, 0, 0, intval(date("n", $current)) + 1, 1, intval(date("Y", $current)));

	$sql_nb = 'SELECT COUNT(date) as nb
		FROM ' . ATTACHVIEW_TABLE . '
		WHERE attach_id = ' . $file . '
			AND date >= ' . $current . ' AND date < ' . $next ;
	$result_nb = $db->sql_query($sql_nb);
	$nb = (int) $db->sql_fetchfield('nb');
	$db->sql_freeresult($result_nb);

	// Send vars to template
	$template->assign_block_vars('stats', array(
		'MONTH'		=> $user->format_date($current, "F Y"),
		'PCT'		=> round($nb/$total_downloads*100),
		'PERCENT'	=> round($nb/$total_downloads*100, 2) . '%',
		'RESULT'	=> $nb
	));

	$current = $next;
}

$template->set_filenames(array(
	'body' => 'attachview_body.html')
);

page_footer();

?>